==> dataiku-dss-14.3.2.tar.gz: dataiku-dss-14.3.2/govern-frontend/assets/logical_hook_base_script.py <==
from govern.core.handler import get_handler

handler = get_handler()
### Get the hookPhase: CREATE | UPDATE | DELETE
hookPhase = handler.hookPhase

### -------------------------------
### Using logging to debug this script
### You can use the logger instance to log info that will be printed in the governserver.log files

# import logging
# logging.basicConfig(level=logging.INFO)
# logger = logging.getLogger(__name__)
# logger.warning('here is a warning')
# logger.info('here an info message')

### -------------------------------
### Get the existing enriched artifact (UPDATE or DELETE phase):

# existingEnrichedArtifact = handler.existingEnrichedArtifact
# existingArtifact = existingEnrichedArtifact.artifact
# existingBlueprintVersion = existingEnrichedArtifact.blueprintVersion

### -------------------------------
### Get the new enriched artifact (CREATE or UPDATE phase):

# newEnrichedArtifact = handler.newEnrichedArtifact
# newArtifact = newEnrichedArtifact.artifact
# newBlueprintVersion = newEnrichedArtifact.blueprintVersion

### -------------------------------
### Edit the current artifact (CREATE or UPDATE phase):

# artifact = handler.artifact

### Change the artifact name:

# artifact.name = "newName"

### To get/set a field given its ID:

# artifact.fields.get("fieldId")
# artifact.fields["fieldId"] = "myNewValue"

### -------------------------------
### To set errors specific to a field (any phase):

# handler.fieldMessages["fieldId"] = "My message here"

### -------------------------------
### To mark the execution of the hook as failed and prevent the action (any phase):

# handler.status = "ERROR"
# handler.message = "The reason why the hook failed"

### -------------------------------
### To specify a list of artifact ids you would like to resave after the execution of this hook.
### This can be useful in case you want to run some other artifacts hooks (any phase):

# handler.artifactIdsToUpdate.append("ar.someArtifactId")

### -------------------------------
### Get the signoff on the current step (CREATE or UPDATE phase):

# signoffs = handler.newEnrichedArtifact.json.get("signoffs", [])
# current_step = next((stepId for (stepId, step) in handler.artifact.json.get('workflow', {}).get('steps', {}).items() if step['status'] == 'ONGOING'), None)
# current_step_signoff = next((s for s in signoffs if s.get("signoffId", {}).get("stepId") == current_step), None)
# current_step_signoff_status = current_step_signoff.get("status") # Values can be: NOT_STARTED, WAITING_FOR_FEEDBACK, WAITING_FOR_APPROVAL, APPROVED, REJECTED, ABANDONED

### -------------------------------
### To use the public api (any phase):
### Warning: do not use any side-effect api calls (artifact create, save, delete) because the script is a pre-save hook

# another_artifact = handler.client.get_artifact("ar.1773")
# another_artifact_definition = another_artifact.get_definition().get_raw()
# another_artifact_current_step = another_artifact_definition.get("status", {}).get("stepId")
# another_artifact_signoff = another_artifact.get_signoff(another_artifact_current_step)
# another_artifact_signoff_status = another_artifact_signoff.get_definition().get_raw().get("status")

==> dataiku-dss-14.4.0.tar.gz: dataiku-dss-14.4.0/govern-frontend/assets/logical_hook_base_script.py <==
from govern.core.handler import get_handler

handler = get_handler()
### Get the hookPhase: CREATE | UPDATE | DELETE
hookPhase = handler.hookPhase

### -------------------------------
### Using logging to debug this script
### You can use the logger instance to log info that will be printed in the governserver.log files

# import logging
# logging.basicConfig(level=logging.INFO)
# logger = logging.getLogger(__name__)
# logger.warning('here is a warning')
# logger.info('here an info message')

### -------------------------------
### Get the existing enriched artifact (UPDATE or DELETE phase):

# existingEnrichedArtifact = handler.existingEnrichedArtifact
# existingArtifact = existingEnrichedArtifact.artifact
# existingBlueprintVersion = existingEnrichedArtifact.blueprintVersion

### -------------------------------
### Get the new enriched artifact (CREATE or UPDATE phase):

# newEnrichedArtifact = handler.newEnrichedArtifact
# newArtifact = newEnrichedArtifact.artifact
# newBlueprintVersion = newEnrichedArtifact.blueprintVersion

### -------------------------------
### Get the auth context identifier that triggered the hook
### It can be an user login or a global API key ID

# auth_ctx_identifier = handler.authCtxIdentifier

### -------------------------------
### Edit the current artifact (CREATE or UPDATE phase):

# artifact = handler.artifact

### Change the artifact name:

# artifact.name = "newName"

### To get/set a field given its ID:

# artifact.fields.get("fieldId")
# artifact.fields["fieldId"] = "myNewValue"

### -------------------------------
### To set errors specific to a field (any phase):

# handler.fieldMessages["fieldId"] = "My message here"

### -------------------------------
### To mark the execution of the hook as failed and prevent the action (any phase):

# handler.status = "ERROR"
# handler.message = "The reason why the hook failed"

### -------------------------------
### To specify a list of artifact ids you would like to resave after the execution of this hook.
### This can be useful in case you want to run some other artifacts hooks (any phase):

# handler.artifactIdsToUpdate.append("ar.someArtifactId")

### -------------------------------
### Get the signoff on the current step (CREATE or UPDATE phase):

# signoffs = handler.newEnrichedArtifact.json.get("signoffs", [])
# current_step = next((stepId for (stepId, step) in handler.artifact.json.get('workflow', {}).get('steps', {}).items() if step['status'] == 'ONGOING'), None)
# current_step_signoff = next((s for s in signoffs if s.get("signoffId", {}).get("stepId") == current_step), None)
# current_step_signoff_status = current_step_signoff.get("status") # Values can be: NOT_STARTED, WAITING_FOR_FEEDBACK, WAITING_FOR_APPROVAL, APPROVED, REJECTED, ABANDONED

### -------------------------------
### To use the public api (any phase):
### Warning: do not use any side-effect api calls (artifact create, save, delete) because the script is a pre-save hook

# another_artifact = handler.client.get_artifact("ar.1773")
# another_artifact_definition = another_artifact.get_definition().get_raw()
# another_artifact_current_step = another_artifact_definition.get("status", {}).get("stepId")
# another_artifact_signoff = another_artifact.get_signoff(another_artifact_current_step)
# another_artifact_signoff_status = another_artifact_signoff.get_definition().get_raw().get("status")
